@@ -2,15 +2,16 @@
 Tests for `bx.binned_array`.
 """
 
+import pytest
 from numpy import (
     allclose,
     concatenate,
-    NaN,
+    nan,
     zeros,
 )
 from numpy.random import random_sample as random
 
-from .binned_array import (
+from bx.binned_array import (
     BinnedArray,
     BinnedArrayWriter,
     FileBinnedArray,
@@ -22,12 +23,9 @@ CHUNK_SIZE_ZEROS = 897
 # CHUNK_SIZE_RANDOM=9456
 # CHUNK_SIZE_ZEROS=8972
 
-source = target = None
 
-
-def setup():
-    global source
-    global target
+@pytest.fixture(scope="module")
+def source_target():
     source = []
     for _ in range(13):
         if random() < 0.5:
@@ -36,14 +34,15 @@ def setup():
             source = concatenate((source, zeros(CHUNK_SIZE_ZEROS, "f")))
     source = source.astype("f")
     # Set on target
-    target = BinnedArray(128, NaN, len(source))
+    target = BinnedArray(128, nan, len(source))
     for i in range(len(source)):
         # if not isNaN( source[i] ):
         target[i] = source[i]
     return source, target
 
 
-def test_simple():
+def test_simple(source_target):
+    source, target = source_target
     # Verify
     for i in range(len(source)):
         assert source[i] == target[i], "No match, index: %d, source: %f, target: %f, len( source ): %d" % (
@@ -66,7 +65,8 @@ def test_simple():
         )
 
 
-def test_file():
+def test_file(source_target):
+    source, target = source_target
     # With a file (zlib)
     target.to_file(open("/tmp/foo", "wb"))
     target2 = FileBinnedArray(open("/tmp/foo", "rb"))
@@ -87,7 +87,8 @@ def test_file():
         )
 
 
-def test_file_lzo():
+def test_file_lzo(source_target):
+    source, target = source_target
     # With a file (lzo)
     target.to_file(open("/tmp/foo3", "wb"), comp_type="lzo")
     target3 = FileBinnedArray(open("/tmp/foo3", "rb"))
@@ -109,7 +110,8 @@ def test_file_lzo():
         )
 
 
-def test_binned_array_writer():
+def test_binned_array_writer(source_target):
+    source, target = source_target
     # Test with ba writer
     o = open("/tmp/foo4", "wb")
     w = BinnedArrayWriter(o, 128, comp_type="lzo")
