@@ -4,7 +4,7 @@ Tests for `bx.seq.fasta`.
 
 import unittest
 
-from . import fasta
+from bx.seq import fasta
 
 test_fa = "test_data/seq_tests/test.fa"
 
