@@ -4,7 +4,7 @@ Tests for `bx.seq.nib`.
 
 import unittest
 
-from . import nib
+from bx.seq import nib
 
 test_nib = "test_data/seq_tests/test.nib"
 
